==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/sc.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Giros",
    "Circles' files" : "Archìvios de is giros",
    "Select circles to filter by" : "Seletziona giros pro filtrare",
    "No circles found" : "Perunu giru agatadu",
    "Please select circles to filter by" : "Seletziona giros pro filtrare",
    "No files found for the selected circles" : "Perunu archìviu agatadu pro is giros seletzionados",
    "You created the circle {circle}" : "As creadu su giru {circle}",
    "{author} created the circle {circle}" : "{author} at creadu su giru {circle}",
    "You deleted {circle}" : "As cantzelladu {circle}",
    "{author} deleted {circle}" : "{author} at cantzelladu {circle}",
    "You linked {group} to {circle}" : "As collegadu {group} a {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} est istadu collegadu a {circle} dae {author}",
    "You unlinked {group} from {circle}" : "As iscrobadu {group} dae {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} est istadu iscrobadu dae {circle} dae {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "As cambiadu su livellu de su grupu collegadu {group} in {circle} cun %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} at cambiadu su livellu de su grupu collegadu {group} in {circle} cun %1$s",
    "You sent a request to link {circle} with {remote}" : "As imbiadu una rechesta pro collegare {circle} cun {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} at imbiadu una rechesta pro collegare {circle} cun {remote}",
    "{remote} requested a link with {circle}" : "{remote} at rechertu unu ligòngiu cun {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Sa rechesta de collegare {circle} cun {remote} est istada refudada",
    "The request to link {remote} with {circle} has been canceled remotely" : "Sa rechesta de collegare {remote} cun {circle} est istada annullada dae remotu",
    "The request to link {circle} with {remote} has been accepted" : "Sa rechesta de collegare {circle} cun {remote} est istada atzetada",
    "You dismissed the request to link {remote} with {circle}" : "As iscartadu sa rechesta de collegare {remote} cun {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} at iscartadu sa rechesta de collegare {remote} cun {circle}",
    "You canceled the request to link {circle} with {remote}" : "As annulladu sa rechesta de collegare {circle} cun{remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} at annulladu sa rechesta de collegare {circle} cun {remote}",
    "You accepted the request to link {remote} with {circle}" : "As atzetadu sa rechesta de collegare {remote} cun{circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} at atzetadu sa rechesta de collegare {remote} cun {circle}",
    "A link between {circle} and {remote} is now up and running" : "Unu ligòngiu intre {circle} e {remote} est ativu immoe",
    "The link between {circle} and {remote} has been shutdown remotely" : "Su ligòngiu intre {circle} e {remote} est istadu istacadu dae remotu",
    "You closed the link between {circle} and {remote}" : "As serradu su ligòngiu intre {circle} e {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} at serradu su ligòngiu intre {circle} e {remote}",
    "You joined {circle}" : "As fatu s'atzessu a {circle}",
    "{member} joined {circle}" : "{member} at fatu s'atzessu a {circle}",
    "You accepted the invitation to join {circle}" : "As atzetadu s'invitu a atzèdere {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} at atzetadu s'invitu a intrare a {circle}",
    "You added {member} as member to {circle}" : "As agiuntu {member} comente cumponente de {circle}",
    "You have been added as member to {circle} by {author}" : "{author} t'at agiuntu comente cumponente de {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} at agiuntu a {member} comente cumponente de {circle}",
    "You added {external} to {circle}" : "As agiuntu a {external} in {circle}",
    "{external} has been added to {circle} by {author}" : "{author} at agiuntu a {external} in {circle}",
    "You accepted {member}'s request to join {circle}" : "As atzetadu sa rechesta de {member} de intrare in {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Sa rechesta tua de intrare in {circle} est istada atzetada dae {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Sa rechesta de {member} de intrare in {circle} est istada atzetada dae {author}",
    "You left {circle}" : "As lassadu {circle}",
    "{member} left {circle}" : "{member} at lassadu {circle}",
    "You declined the invitation to join {circle}" : "As refudadu s'invitu a intrare in {circle}",
    "{member} declined an invitation to join {circle}" : "{member} at refudadu un'invitu a intrare in {circle}",
    "You cancelled your request to join {circle}" : "As annulladu sa rechesta de intrare in {circle}",
    "{member} cancelled his request to join {circle}" : "{member} at annulladu sa rechesta de intrare in {circle}",
    "You removed {member} from {circle}" : "As bogadu a {member} dae {circle}",
    "You have been removed from {circle} by {author}" : "{author} ti nch'at bogadu dae {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} nch'at bogadu a {member} dae {circle}",
    "You removed {external} from {circle}" : "As bogadu a {external} dae {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} nch'at bogadu a {external} dae {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "As annulladu s'invitu de {member} a intrare in {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "S'invitu a intrare in {circle} dd'at annulladu {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} at annulladu s'invitu de {member} de intrare in{circle}",
    "You dismissed {member}'s request to join {circle}" : "As iscartadu sa rechesta de {member} de intrare in {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Sa rechesta tua de intrare in {circle} dd'at iscartada {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "sa rechesta de {member} de intrare in {circle} est istada iscartada dae {author}",
    "You invited {member} to join {circle}" : "As invitadu a {member} a intrare in {circle}",
    "You have been invited to join {circle} by {author}" : "{author} t'at invitadu a intrare in {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} at invitadu a {member} a intrare in {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "As cambiadu su livellu de {member} in {circle} cun %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} at cambiadu su livellu tuo in {circle} cun %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} at cambiadu su livellu de {member} in {circle} cun %1$s",
    "You sent a request to join {circle}" : "As imbiadu una rechesta pro intrare in {circle}",
    "{member} sent a request to join {circle}" : "{member} at imbiadu una rechesta pro intrare in {circle}",
    "You are the new owner of {circle}" : "Ses mere de {circle}",
    "{member} is the new owner of {circle}" : "{member} immoe est mere de {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Pro is eventos de unu <strong>Giru</strong> de su chi ses cumponente",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Cale si siat eventu importante in un <strong>Giru</strong> chi ses moderende",
    "On global events happening in any <strong>Circle</strong>" : "Pro is eventos globales de cale si siat <strong>Giru</strong>",
    "Single" : "Ùnicu",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Visible" : "Visìbile",
    "Open" : "Aberi",
    "Invite" : "Invita",
    "Join Request" : "Rechesta de intrada",
    "Friends" : "Amighèntzias",
    "Password Protected" : "Crae bardiada",
    "No Owner" : "Peruna propiedade",
    "Hidden" : "Cuadu",
    "Backend" : "Motore",
    "Local" : "Locale",
    "Root" : "Sorgente",
    "Circle Invite" : "Invitu in su giru",
    "Federated" : "Federadu",
    "Mount point" : "Puntu de montàgiu",
    "Nextcloud Group" : "Grupu de Nextcloud",
    "Email Address" : "Indiritzu de posta eletrònica",
    "Contact" : "Cuntatu",
    "Circle" : "Giru",
    "Nextcloud App" : "Aplicatzione de Nextcloud",
    "Member" : "Membru",
    "Moderator" : "Chie moderat",
    "Admin" : "Amministratzione",
    "Owner" : "Mere",
    "%s shared »%s« with you." : "%s at cumpartzidu »%s« cun tegus.",
    "%s shared »%s« with \"%s\"." : "%s at cumpartzidu »%s« cun \"%s\".",
    "%s on %s" : "%s in %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s at cumpartzidu »%2$s« cun tegus.\nDias dèpere àere giai retzidu unu messàgiu de posta seberadu cun unu ligòngiu pro intrare.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s at cumpartzidu »%2$s« cun tegus. Dias dèpere àere giai retzidu unu messàgiu de posta seberadu cun unu ligòngiu pro intrare.",
    "Password to access »%1$s« shared to you by %2$s" : "Crae pro s'atzessu »%1$s« cumpartzida cun tegus dae %2$s",
    "Password to access »%s«" : "Crae pro s'atzessu »%s«",
    "It is protected with the following password:" : "Est amparadu cun sa crae in fatu:",
    "%1$s via %2$s" : "%1$s cun %2$s",
    "Click the button below to open it." : "Incarca su butone a suta pro dd'abèrrere.",
    "Open »%s«" : "Aberi »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s at cumpartzìdu archìvios mùltiplos cun tegus.\nDias dèpere àere giai retzidu unu messàgiu de posta seberadu cun unu ligòngiu pro intrare.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s at cumpartzidu archìvios mùltiplos cun tegus. Dias dèpere àere giai retzidu unu messàgiu de posta seberadu cun unu ligòngiu pro intrare.",
    "Password to access files shared to you by %1$s" : "Crae pro intrare in is archìvios cumpartzidos cun tegus dae %1$s",
    "Password to access files" : "Crae pro intrare in is archìvios",
    "%s shared multiple files with \"%s\"." : "%s at cumpartzidu archìvios mùltiplos cun \"%s\".",
    "%s shared multiple files with you." : "%s at cumpartzidu prus archìvios cun te.",
    "Boot up" : "Avia",
    "Initialisation Nextcloud" : "Apariciamentu de Nextcloud",
    "Initialisation Circles App" : "Apariciamentu de s'aplicatzione Giros",
    "Fresh installation status" : "Istadu de s'installatzione noa",
    "Building Local Database" : "Creschende sa base de datos locale",
    "Testing Basic Circle Creation" : " Proa de creatzione de giru de base",
    "Adding local users and moderators" : "Agiunta de utentes locales e persones chi moderent",
    "Circle not found" : "Giru no agatadu",
    "Circle not found " : "Giru no agatadu",
    "A circle with that name exists" : "B'at giai unu giru cun cussu nùmene",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Non podes impreare s'aplicatzione de is giros finas a cando s'amministratzione at a permìtere a su mancu una genia de giru",
    "This member does not exist" : "Custa persone no esistit",
    "Federated link not found" : "Ligòngiu federadu no agatadu",
    "This feature is not available for personal circles" : "Sa funtzionalidade no est a disponimentu pro giros personales",
    "The circle is not federated" : "Su giru no est federadu",
    "You cannot join this circle" : "Non podes intrare in custu giru",
    "This member is not a moderator" : "Custa persone no est chie mòderat",
    "Insufficient privileges" : "Permissos non sufitzientes",
    "This member is the owner of the circle" : "Custa persone est mere de su giru",
    "Level cannot be changed for this type of member" : "Non faghet a cambiare su livellu pro custa genia de cumponente",
    "You are already a member of this circle" : "Ses giai cumponente de custu giru",
    "You have been blocked from this circle" : "T'ant blocadu dae custu giru",
    "You are now a member of the Circle \"%2$s\"" : "Immoe ses cumponente de \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s t'at invitadu a su giru \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s at imbiadu una rechesta pro èssere cumponente de su giru \"%2$s\"",
    "Accept" : "Atzeta",
    "Refuse" : "Refuda",
    "Leave the circle" : "Lassa su giru",
    "%s" : "%s",
    "Personal Circle" : "Giru personale",
    "%s owned by %s" : "%s de propiedade de %s",
    "You need a specify a type of circle" : "Depes tènnere una genia de giru ispetzìfica",
    "This member is not the owner of the circle" : "Custa persone no est mere de su giru",
    "This member is not an admin of the circle" : "Custa persone no est de s'amministratzione de su giru",
    "Group contains too many members" : "Su grupu tenet tropu membros",
    "This group does not exist" : "Custu grupu no esistit",
    "This group is already linked to the circle" : "Custu grupu est giai collegadu cun unu giru",
    "You cannot edit level in a personal circle" : "Non podes editare su livellu in unu giru personale",
    "Group cannot be set as owner of a circle" : "Non faghet a impostare su grupu comente mere de su giru",
    "now" : "immoe",
    "Email format is not valid" : "Su formadu de s'indiritzu de posta no est vàlidu",
    "This contact is not available" : "Custu cuntatu no est a disponimentu",
    "%s shared a file with \"%s\"." : "%s at cumpartzidu un'archìviu cun \"%s\".",
    "%s shared a file with you." : "%s at cumpartzidu un'archìviu cun tegus.",
    "This item is already shared with this circle" : "Custu elementu est giai istadu cumpartzidu cun custu giru",
    "Could not find share" : "No at fatu a agatare sa cumpartzidura",
    "Bring cloud-users closer together." : "Acosta impare a is utentes de sa nue.",
    "No files in here" : "Perunu archìviu",
    "No entries found in this folder" : "Perunu elementu agatadu in custa cartella",
    "Name" : "Nùmene",
    "Size" : "Mannària",
    "Modified" : "Modificadu",
    "Nextcloud User" : "Utente de Nextcloud",
    "This user is already a member of the circle" : "Custa utèntzia faghet giai parte de su giru",
    "The user is already a member of this circle" : "S'utente est giai cumponente de custu giru",
    "The user has already been invited into this circle" : "Ant giai invitadu a s'utente a custu giru",
    "This user does not exist" : "S'utente no esistit",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Giros permitit a is utentes tuos de creare is grupos issoro de utentes/collegas/amistades.\nCustos grupos de utentes (o \"giros\") podent duncas èssere impreados dae calesisiat àtera aplicatzione pro is cumpartziduras."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/sc.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "As cantzelladu {circle}",
    "{author} deleted {circle}" : "{author} at cantzelladu {circle}",
    "You removed {member} from {circle}" : "As bogadu a {member} dae {circle}",
    "You joined {circle}" : "As fatu s'atzessu a {circle}",
    "{member} joined {circle}" : "{member} at fatu s'atzessu a {circle}",
    "You accepted the invitation to join {circle}" : "As atzetadu s'invitu a atzèdere {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} at atzetadu s'invitu a intrare a {circle}",
    "You added {member} as member to {circle}" : "As agiuntu {member} comente cumponente de {circle}",
    "You have been added as member to {circle} by {author}" : "{author} t'at agiuntu comente cumponente de {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} at agiuntu a {member} comente cumponente de {circle}",
    "You added {external} to {circle}" : "As agiuntu a {external} in {circle}",
    "{external} has been added to {circle} by {author}" : "{author} at agiuntu a {external} in {circle}",
    "You accepted {member}'s request to join {circle}" : "As atzetadu sa rechesta de {member} de intrare in {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Sa rechesta tua de intrare in {circle} est istada atzetada dae {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Sa rechesta de {member} de intrare in {circle} est istada atzetada dae {author}",
    "You left {circle}" : "As lassadu {circle}",
    "{member} left {circle}" : "{member} at lassadu {circle}",
    "You declined the invitation to join {circle}" : "As refudadu s'invitu a intrare in {circle}",
    "{member} declined an invitation to join {circle}" : "{member} at refudadu un'invitu a intrare in {circle}",
    "You cancelled your request to join {circle}" : "As annulladu sa rechesta de intrare in {circle}",
    "You have been removed from {circle} by {author}" : "{author} ti nch'at bogadu dae {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} nch'at bogadu a {member} dae {circle}",
    "You removed {external} from {circle}" : "As bogadu a {external} dae {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} nch'at bogadu a {external} dae {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "As annulladu s'invitu de {member} a intrare in {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "S'invitu a intrare in {circle} dd'at annulladu {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} at annulladu s'invitu de {member} de intrare in{circle}",
    "You dismissed {member}'s request to join {circle}" : "As iscartadu sa rechesta de {member} de intrare in {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Sa rechesta tua de intrare in {circle} dd'at iscartada {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "sa rechesta de {member} de intrare in {circle} est istada iscartada dae {author}",
    "You invited {member} to join {circle}" : "As invitadu a {member} a intrare in {circle}",
    "You have been invited to join {circle} by {author}" : "{author} t'at invitadu a intrare in {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} at invitadu a {member} a intrare in {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "As cambiadu su livellu de {member} in {circle} cun %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} at cambiadu su livellu tuo in {circle} cun %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} at cambiadu su livellu de {member} in {circle} cun %1$s",
    "You sent a request to join {circle}" : "As imbiadu una rechesta pro intrare in {circle}",
    "{member} sent a request to join {circle}" : "{member} at imbiadu una rechesta pro intrare in {circle}",
    "You are the new owner of {circle}" : "Ses mere de {circle}",
    "{member} is the new owner of {circle}" : "{member} immoe est mere de {circle}",
    "Single" : "Ùnicu",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Visible" : "Visìbile",
    "Open" : "Aberi",
    "Invite" : "Invita",
    "Friends" : "Amighèntzias",
    "Password protected" : "Crae bardiada",
    "No Owner" : "Peruna propiedade",
    "Hidden" : "Cuadu",
    "Backend" : "Motore",
    "Local" : "Locale",
    "Root" : "Sorgente",
    "Federated" : "Federadu",
    "Mount point" : "Puntu de montàgiu",
    "Nextcloud Group" : "Grupu de Nextcloud",
    "Email address" : "Indiritzu de posta eletrònica",
    "Contact" : "Cuntatu",
    "Circle" : "Giru",
    "Nextcloud App" : "Aplicatzione de Nextcloud",
    "Member" : "Membru",
    "Moderator" : "Chie moderat",
    "Admin" : "Amministratzione",
    "Owner" : "Mere",
    "%s shared »%s« with you." : "%s at cumpartzidu »%s« cun tegus.",
    "%s shared »%s« with \"%s\"." : "%s at cumpartzidu »%s« cun \"%s\".",
    "%s on %s" : "%s in %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s at cumpartzidu »%2$s« cun tegus.\nDias dèpere àere giai retzidu unu messàgiu de posta seberadu cun unu ligòngiu pro intrare.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s at cumpartzidu »%2$s« cun tegus. Dias dèpere àere giai retzidu unu messàgiu de posta seberadu cun unu ligòngiu pro intrare.",
    "Password to access »%1$s« shared to you by %2$s" : "Crae pro s'atzessu »%1$s« cumpartzida cun tegus dae %2$s",
    "Password to access »%s«" : "Crae pro s'atzessu »%s«",
    "It is protected with the following password:" : "Est amparadu cun sa crae in fatu:",
    "%1$s via %2$s" : "%1$s cun %2$s",
    "Click the button below to open it." : "Incarca su butone a suta pro dd'abèrrere.",
    "Open »%s«" : "Aberi »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s at cumpartzìdu archìvios mùltiplos cun tegus.\nDias dèpere àere giai retzidu unu messàgiu de posta seberadu cun unu ligòngiu pro intrare.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s at cumpartzidu archìvios mùltiplos cun tegus. Dias dèpere àere giai retzidu unu messàgiu de posta seberadu cun unu ligòngiu pro intrare.",
    "Password to access files shared to you by %1$s" : "Crae pro intrare in is archìvios cumpartzidos cun tegus dae %1$s",
    "Password to access files" : "Crae pro intrare in is archìvios",
    "%s shared multiple files with \"%s\"." : "%s at cumpartzidu archìvios mùltiplos cun \"%s\".",
    "%s shared multiple files with you." : "%s at cumpartzidu prus archìvios cun te.",
    "Boot up" : "Avia",
    "Fresh installation status" : "Istadu de s'installatzione noa",
    "Building Local Database" : "Creschende sa base de datos locale",
    "Testing Basic Circle Creation" : " Proa de creatzione de giru de base",
    "Adding local users and moderators" : "Agiunta de utentes locales e persones chi moderent",
    "Create a new team" : "Crea un'iscuadra noa",
    "Files" : "Archìvios",
    "This feature is not available for personal circles" : "Sa funtzionalidade no est a disponimentu pro giros personales",
    "This member is not a moderator" : "Custa persone no est chie mòderat",
    "Insufficient privileges" : "Permissos non sufitzientes",
    "This member does not exist" : "Custa persone no esistit",
    "Level cannot be changed for this type of member" : "Non faghet a cambiare su livellu pro custa genia de cumponente",
    "You are already a member of this circle" : "Ses giai cumponente de custu giru",
    "You have been blocked from this circle" : "T'ant blocadu dae custu giru",
    "Accept" : "Atzeta",
    "Refuse" : "Refuda",
    "%s" : "%s",
    "%s owned by %s" : "%s de propiedade de %s",
    "You have no permission to create a new team" : "Non tenes permissu pro creare un'iscuadra noa",
    "%s shared a file with \"%s\"." : "%s at cumpartzidu un'archìviu cun \"%s\".",
    "%s shared a file with you." : "%s at cumpartzidu un'archìviu cun tegus.",
    "Open %s" : "Aberi %s",
    "Bring cloud-users closer together." : "Acosta impare a is utentes de sa nue.",
    "No files in here" : "Perunu archìviu",
    "No entries found in this folder" : "Perunu elementu agatadu in custa cartella",
    "Name" : "Nùmene",
    "Size" : "Mannària",
    "Modified" : "Modificadu",
    "Shared to Circles" : "Cumpartzidu cun is giros\\"
},
"nplurals=2; plural=(n != 1);");
